@@ -3,15 +3,6 @@ import threading
 from queue import Empty
 
 
-class Engine(object):
-
-    def __init__(self, connect):
-        self._connect = connect
-
-    def connect(self):
-        return self._connect()
-
-
 class TDCtx(threading.local):
     """
     Thread local object that holds connection info.
@@ -76,7 +67,7 @@ class ConnectionCtx(object):
             self.should_cleanup = True
         return self
 
-    def __exit__(self, exctype, excvalue, traceback):
+    def __exit__(self, exc_type, exc_value, traceback):
         if self.should_cleanup:
             self.db_ctx.release()
 
@@ -133,3 +124,10 @@ class Dict(dict):
     def __setattr__(self, key, value):
         self[key] = value
 
+
+class SqlModel:
+
+    def __init__(self, sql, dynamic=False):
+        self.sql = sql
+        self.dynamic = dynamic
+
