@@ -3,35 +3,35 @@ import logging
 import functools
 from taostd import cache
 from datetime import datetime, timedelta
-from taostd.model import TDCtx, TDError, Engine, ConnectionCtx, Dict, MultiColumnsError
+from taostd.model import TDCtx, TDError, ConnectionCtx, Dict, MultiColumnsError
 from taostd.bind import bind_params, batch_bind_params
 from taostd.sql import get_sql_tags, get_sql_values, get_insert_sql
 from queue import Queue
 import copy
 
 # connection pool
-_pool = None
+_POOL = None
 # thread-local context:
-_db_ctx = None
-_tz_offset = None
+_DB_CTX = None
+_TZ_OFFSET = None
 
 
-def init_db(database, pool_size=1, tz_offset=8, *args, **kwargs):
-    global _pool
-    global _db_ctx
-    global _tz_offset
-    _tz_offset = tz_offset
-    if _pool is not None:
+def init_db(database, pool_size=2, tz_offset=8, *args, **kwargs):
+    global _POOL
+    global _DB_CTX
+    global _TZ_OFFSET
+    _TZ_OFFSET = tz_offset
+    if _DB_CTX is not None:
         logging.warning('DB is already initialized.')
         return
 
     kwargs['database'] = database
-    _pool = Queue(maxsize=pool_size)
+    _POOL = Queue(maxsize=pool_size)
     for _ in range(pool_size):
-        _pool.put_nowait(taos.connect(*args, **kwargs))
-    _db_ctx = TDCtx(_pool)
+        _POOL.put_nowait(taos.connect(*args, **kwargs))
+    _DB_CTX = TDCtx(_POOL)
     # examples connection...
-    logging.info('Init TDengine engine <%s> ok.' % hex(id(_pool)))
+    logging.info('Init TDengine <%s> ok.' % hex(id(_DB_CTX)))
 
     _init_table_cache()
 
@@ -42,8 +42,8 @@ def connection():
     with connection():
         pass
     """
-    global _db_ctx
-    return ConnectionCtx(_db_ctx)
+    global _DB_CTX
+    return ConnectionCtx(_DB_CTX)
 
 
 def with_connection(func):
@@ -55,11 +55,11 @@ def with_connection(func):
         f2()
         f3()
     """
-    global _db_ctx
+    global _DB_CTX
 
     @functools.wraps(func)
     def _wrapper(*args, **kw):
-        with ConnectionCtx(_db_ctx):
+        with ConnectionCtx(_DB_CTX):
             return func(*args, **kw)
 
     return _wrapper
@@ -145,12 +145,12 @@ def insert_one_with_stable(table: str, stable: str, **kwargs):
     :param kwargs: values: {field: value}, tags are not necessary
     :return: affected_rows
     """
-    global _tz_offset
+    global _TZ_OFFSET
     cache_stable = _get_table_cache(table)
     if cache_stable is None:
         desc = _get_stable_cache(stable)
         num_columns = desc['columns']
-        params = bind_params(num_columns, _tz_offset, desc['fields'], **kwargs)
+        params = bind_params(num_columns, _TZ_OFFSET, desc['fields'], **kwargs)
         return _insert_one_with_stable(table, stable, num_columns, desc, params, **kwargs)
     elif cache_stable != stable:
         raise TDError(f"expect stable '{cache_stable}'，but input '{stable}'.")
@@ -266,19 +266,19 @@ def _init_table_cache():
 
 
 def _query(sql: str):
-    global _db_ctx
+    global _DB_CTX
     logging.debug('SQL: %s' % sql)
-    return _db_ctx.connection.query(sql)
+    return _DB_CTX.connection.query(sql)
 
 
 def _stmt_execute(sql: str, args):
     """
     :return: TaosResult
     """
-    global _db_ctx
+    global _DB_CTX
     stmt = None
     try:
-        stmt = _db_ctx.statement(sql)
+        stmt = _DB_CTX.statement(sql)
         if isinstance(args, list):
             for arg in args:
                 stmt.bind_param(arg)
@@ -293,10 +293,10 @@ def _stmt_execute(sql: str, args):
 
 
 def _cursor_execute(sql: str):
-    global _db_ctx
+    global _DB_CTX
     cursor = None
     try:
-        cursor = _db_ctx.cursor()
+        cursor = _DB_CTX.cursor()
         return cursor.execute(sql)
     finally:
         if cursor:
@@ -330,7 +330,6 @@ def _get_stable_cache(stable: str):
 
     stables = _select(f"show stables like '{stable}'")
     for stbl in stables:
-        print(stbl, stable)
         if stbl['name'] == stable:
             fields = _select(f"describe {stable}")
             fields = [_del_field_length(f) for f in fields]
@@ -355,10 +354,10 @@ def _insert_one(table: str, stable: str, **kwargs):
     :param kwargs: values: {field: value}, tags are not necessary
     :return: affected_rows
     """
-    global _tz_offset
+    global _TZ_OFFSET
     desc = _get_stable_cache(stable)
     num_columns = desc['columns']
-    params = bind_params(num_columns, _tz_offset, desc['fields'], **kwargs)
+    params = bind_params(num_columns, _TZ_OFFSET, desc['fields'], **kwargs)
     sql = get_insert_sql(table, num_columns)
     logging.debug('SQL: %s' % sql)
     try:
@@ -382,8 +381,8 @@ def _insert_one_with_stable(table, stable, num_columns, desc, params, **kwargs):
 
 
 def _batch_stmt_execute(sql, num_columns, fields, args: list):
-    global _tz_offset
-    params = batch_bind_params(num_columns, _tz_offset, fields, args)
+    global _TZ_OFFSET
+    params = batch_bind_params(num_columns, _TZ_OFFSET, fields, args)
     return _stmt_execute(sql, params).affected_rows
 
 
@@ -396,7 +395,7 @@ def _insert_many_with_stable(table: str, stable: str, num_columns, desc, args: l
 
 
 def _insert_many(table: str, stable: str, args: list, batch_size=1000):
-    global _tz_offset
+    global _TZ_OFFSET
     desc = _get_stable_cache(stable)
     num_columns = desc['columns']
     sql = get_insert_sql(table, num_columns)
